# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright (C) 2014 Xavier Bruhiere
#
# Distributed under terms of the MIT license.


import jinja2
import os


def generate(completion, templates_path, template, target):
    tpl_env = jinja2.Environment(
        loader=jinja2.FileSystemLoader(templates_path))
    template = tpl_env.get_template(template)
    document = template.render(completion)

    #fd = open(os.path.join(templates_path, target), 'w')
    fd = open(target, 'w')
    fd.write(document)
    fd.close()


def format_title(title):
    #return ' '.join(map(str.capitalize, title[2:].split('-')))
    return ' '.join(map(str.capitalize, title.split('-')))


def add_section(doc, path, name, subsections):
    doc['layout'].append({
        'name': name,
        'title': format_title(name),
        'path': path,
        'subsections': subsections})


def add_subsection(doc, name):
    doc.append({
        'name': name,
        'title': format_title(name)})


def _walk_callback(tree, dirname, fnames):
    path = dirname.split('/')
    if path[-2] == 'articles':
        fnames.sort()
        tree.update({
            path[-1]: filter(
                lambda x: (x.find('.md') > 0) and
                (x.find('index') < 0), fnames)})
    return tree


def inspect_articles(path):
    tree = {}
    os.path.walk(path, _walk_callback, tree)
    return tree


def build(target):
    completion = {'layout': []}
    articles_path = os.path.join(target, 'source/articles')
    templates_path = os.path.expanduser('~/.okdoc')
    layout_target_file = os.path.join(target, 'source/layouts/layout.erb')

    print 'scanning source/articles'
    tree = inspect_articles(articles_path)

    print 'registering content'
    for directory in sorted(tree):
        articles = []
        for article in tree[directory]:
            add_subsection(articles, article[:-3])
        add_section(completion, 'articles', directory, articles)

    print 'generating layout'
    generate(completion,
             templates_path=templates_path,
             template='section.tpl',
             target=layout_target_file)
